@@ -91,20 +91,20 @@ def get_reference(base_url: str, ref: str, ssl_verify: bool = True) -> dict:
     :param base_url: base Nessie url
     :param ref: name of ref to fetch
     :param ssl_verify: ignore ssl errors if False
-    :return: json Nessie branch
+    :return: json Nessie branch or tag
     """
     return cast(dict, _get(base_url + "/trees/tree/{}".format(ref), ssl_verify=ssl_verify))
 
 
-def create_reference(base_url: str, ref_json: dict, ssl_verify: bool = True) -> None:
+def create_reference(base_url: str, ref_json: dict, ssl_verify: bool = True) -> dict:
     """Create a reference.
 
     :param base_url: base Nessie url
-    :param ref: reference to create as json object
+    :param ref_json: reference to create as json object
     :param ssl_verify: ignore ssl errors if False
-    :return: json Nessie branch
+    :return: json Nessie branch or tag
     """
-    _post(base_url + "/trees/tree", ref_json, ssl_verify=ssl_verify)
+    return cast(dict, _post(base_url + "/trees/tree", ref_json, ssl_verify=ssl_verify))
 
 
 def get_default_branch(base_url: str, ssl_verify: bool = True) -> dict:
@@ -170,24 +170,16 @@ def list_tables(
     return cast(list, _get(base_url + "/trees/tree/{}/entries".format(ref), ssl_verify=ssl_verify, params=params))
 
 
-def list_logs(
-    base_url: str, ref: str, max_result_hint: Optional[int] = None, page_token: Optional[str] = None, ssl_verify: bool = True
-) -> dict:
+def list_logs(base_url: str, ref: str, ssl_verify: bool = True, **filtering_args: Any) -> dict:
     """Fetch a list of all logs from a known starting reference.
 
     :param base_url: base Nessie url
     :param ref: starting reference
-    :param max_result_hint: hint for the server, maximum number of results to return
-    :param page_token: the token retrieved from a previous page returned for the same ref
     :param ssl_verify: ignore ssl errors if False
+    :param filtering_args: All of the args used to filter the log
     :return: json dict of Nessie logs
     """
-    params = {}
-    if max_result_hint:
-        params["max"] = str(max_result_hint)
-    if page_token:
-        params["pageToken"] = page_token
-    return cast(dict, _get(base_url + "/trees/tree/{}/log".format(ref), ssl_verify=ssl_verify, params=params))
+    return cast(dict, _get(base_url + "/trees/tree/{}/log".format(ref), ssl_verify=ssl_verify, params=filtering_args))
 
 
 def get_table(base_url: str, ref: str, table: str, ssl_verify: bool = True) -> dict:
@@ -288,7 +280,7 @@ def commit(
     operations: str,
     expected_hash: str,
     ssl_verify: bool = True,
-) -> None:
+) -> dict:
     """Commit a set of operations to a branch.
 
     :param base_url: base Nessie url
@@ -299,4 +291,4 @@ def commit(
     """
     url = "/trees/branch/{}/commit".format(branch)
     params = {"expectedHash": expected_hash}
-    _post(base_url + url, json=operations, ssl_verify=ssl_verify, params=params)
+    return cast(dict, _post(base_url + url, json=operations, ssl_verify=ssl_verify, params=params))
