@@ -7,6 +7,8 @@ from typing import Any
 from typing import Dict
 from typing import Generator
 from typing import List
+from typing import Mapping
+from typing import Optional
 from typing import Tuple
 
 import attr
@@ -65,7 +67,7 @@ class MutuallyExclusiveOption(Option):
         self.mutually_exclusive = set(kwargs.pop("mutually_exclusive", []))
         super(MutuallyExclusiveOption, self).__init__(*args, **kwargs)  # type: ignore
 
-    def handle_parse_result(self: "MutuallyExclusiveOption", ctx: click.Context, opts: Dict, args: List) -> Tuple[Any, List[str]]:
+    def handle_parse_result(self: "MutuallyExclusiveOption", ctx: click.Context, opts: Mapping, args: List) -> Tuple[Any, List[str]]:
         """Ensure mutually exclusive options are not used together."""
         if self.mutually_exclusive.intersection(opts) and self.name in opts:
             raise UsageError(
@@ -176,15 +178,34 @@ def set_head(ctx: ContextObject, head: str, delete: bool) -> None:
 
 
 @cli.command("log")
-@click.option("-n", "--number", help="number of log entries to return", type=int, default=-1)
-@click.option("--since", "--after", help="Commits more recent than specific date")
-@click.option("--until", "--before", help="Commits older than specific date")
-@click.option("--author", "--committer", is_flag=True, help="limit commits to specific committer")
+@click.option("-n", "--number", help="number of log entries to return", type=int)
+@click.option("--since", "--after", help="Only include commits newer than specific date")
+@click.option("--until", "--before", help="Only include commits older than specific date")
+@click.option(
+    "--author",
+    multiple=True,
+    help="Limit commits to a specific author (this is the original committer). Supports specifying multiple authors to filter by.",
+)
+@click.option(
+    "--committer",
+    multiple=True,
+    help="Limit commits to a specific committer (this is the logged in user/account who performed the commit). "
+    "Supports specifying multiple committers to filter by.",
+)
 @click.argument("revision_range", nargs=1, required=False)
 @click.argument("paths", nargs=-1, type=click.Path(exists=False), required=False)
 @pass_client
 @error_handler
-def log(ctx: ContextObject, number: int, since: str, until: str, author: str, revision_range: str, paths: Tuple[click.Path]) -> None:
+def log(
+    ctx: ContextObject,
+    number: int,
+    since: str,
+    until: str,
+    author: List[str],
+    committer: List[str],
+    revision_range: str,
+    paths: Tuple[click.Path],
+) -> None:
     """Show commit log.
 
     REVISION_RANGE optional branch, tag or hash to start viewing log from. If of the form <hash>..<hash> only show log
@@ -202,7 +223,21 @@ def log(ctx: ContextObject, number: int, since: str, until: str, author: str, re
             start = revision_range
             end = None
 
-    log_result = show_log(ctx.nessie, start, number, since, until, author, end, paths)
+    filtering_args: Any = {}
+    if number:
+        filtering_args["max"] = str(number)
+    if author:
+        filtering_args["authors"] = author
+    if committer:
+        filtering_args["committers"] = committer
+    if since:
+        filtering_args["after"] = since
+    if until:
+        filtering_args["before"] = until
+    if end:
+        filtering_args["end"] = end
+
+    log_result = show_log(nessie=ctx.nessie, start_ref=start, limits=paths, **filtering_args)
     if ctx.json:
         click.echo(CommitMetaSchema().dumps(log_result, many=True))
     else:
@@ -314,8 +349,8 @@ def tag(ctx: ContextObject, list: bool, force: bool, delete: bool, tag_name: str
 
 
 @cli.command("merge")
-@click.option("-b", "--branch", help="branch to merge onto. If not supplied the default branch from config is used")
-@click.argument("merge_branch", nargs=1, required=False)
+@click.option("-b", "--branch", "onto_branch", help="branch to merge onto. If not supplied the default branch from config is used")
+@click.argument("from_branch", nargs=1, required=False)
 @click.option(
     "-f",
     "--force",
@@ -333,14 +368,14 @@ def tag(ctx: ContextObject, list: bool, force: bool, delete: bool, tag_name: str
 )
 @pass_client
 @error_handler
-def merge(ctx: ContextObject, branch: str, force: bool, condition: str, merge_branch: str) -> None:
-    """Merge BRANCH into current branch. BRANCH can be a hash or branch."""
+def merge(ctx: ContextObject, onto_branch: str, force: bool, condition: str, from_branch: str) -> None:
+    """Merge FROM_BRANCH into current branch. FROM_BRANCH can be a hash or branch."""
     if not force and not condition:
         raise UsageError(
             """Either condition or force must be set. Condition should be set to a valid hash for concurrency
             control or force to ignore current state of Nessie Store."""
         )
-    ctx.nessie.merge(branch if branch else ctx.nessie.get_default_branch(), merge_branch, condition)
+    ctx.nessie.merge(from_branch, onto_branch if onto_branch else ctx.nessie.get_default_branch(), condition)
     click.echo()
 
 
@@ -414,11 +449,21 @@ def cherry_pick(ctx: ContextObject, branch: str, force: bool, condition: str, ha
     help="entity types to filter on, if no entity types are passed then all types are returned",
     multiple=True,
 )
+@click.option("--author", help="The author to use for the commit")
 @click.argument("key", nargs=-1, required=False)
 @pass_client
 @error_handler
 def contents(
-    ctx: ContextObject, list: bool, delete: bool, set: bool, key: List[str], ref: str, message: str, condition: str, entity_type: list
+    ctx: ContextObject,
+    list: bool,
+    delete: bool,
+    set: bool,
+    key: List[str],
+    ref: str,
+    message: str,
+    condition: str,
+    entity_type: list,
+    author: str,
 ) -> None:
     """Contents operations.
 
@@ -428,10 +473,10 @@ def contents(
         keys = ctx.nessie.list_keys(ref if ref else ctx.nessie.get_default_branch(), entity_types=entity_type)
         results = EntrySchema().dumps(_format_keys_json(keys, *key), many=True) if ctx.json else _format_keys(keys, *key)
     elif delete:
-        ctx.nessie.commit(ref, condition, _get_message(message), *_get_contents(ctx.nessie, ref, delete, *key))
+        ctx.nessie.commit(ref, condition, _get_message(message), author, *_get_contents(ctx.nessie, ref, delete, *key))
         results = ""
     elif set:
-        ctx.nessie.commit(ref, condition, _get_message(message), *_get_contents(ctx.nessie, ref, delete, *key))
+        ctx.nessie.commit(ref, condition, _get_message(message), author, *_get_contents(ctx.nessie, ref, delete, *key))
         results = ""
     else:
 
@@ -453,6 +498,7 @@ def _get_contents(nessie: NessieClient, ref: str, delete: bool = False, *keys: s
             content_json = click.get_text_stream("stdin").read()
 
         MARKER = "# Everything below is ignored\n"
+        message: Optional[str] = None
         if delete:
             message = "\n\n" + MARKER
         else:
@@ -478,14 +524,13 @@ def _get_contents(nessie: NessieClient, ref: str, delete: bool = False, *keys: s
     return contents_altered
 
 
-def _get_commit_message(*keys: str) -> str:
+def _get_commit_message(*keys: str) -> Optional[str]:
     MARKER = "# Everything below is ignored\n"
     message = click.edit("\n\n" + MARKER + "\n".join(keys))
-    if message is not None:
-        return message.split(MARKER, 1)[0].rstrip("\n")
+    return message.split(MARKER, 1)[0].rstrip("\n") if message is not None else None
 
 
-def _get_message(message: str, *keys: str) -> str:
+def _get_message(message: str, *keys: str) -> Optional[str]:
     if message:
         return message
     return _get_commit_message(*keys)
