@@ -78,14 +78,16 @@ class NessieClient(object):
         ref = ReferenceSchema().load(ref_obj)
         return ref
 
-    def create_branch(self: "NessieClient", branch: str, ref: str = None) -> None:
+    def create_branch(self: "NessieClient", branch: str, ref: str = None) -> Branch:
         """Create a branch.
 
         :param branch: name of new branch
         :param ref: ref to fork from
+        :return: Nessie branch object
         """
         ref_json = ReferenceSchema().dump(Branch(branch, ref))
-        create_reference(self._base_url, ref_json, self._ssl_verify)
+        ref_obj = create_reference(self._base_url, ref_json, self._ssl_verify)
+        return cast(Branch, ReferenceSchema().load(ref_obj))
 
     def delete_branch(self: "NessieClient", branch: str, hash_: str) -> None:
         """Delete a branch.
@@ -95,14 +97,16 @@ class NessieClient(object):
         """
         delete_branch(self._base_url, branch, hash_, self._ssl_verify)
 
-    def create_tag(self: "NessieClient", tag: str, ref: str = None) -> None:
+    def create_tag(self: "NessieClient", tag: str, ref: str = None) -> Tag:
         """Create a tag.
 
         :param tag: name of new tag
         :param ref: ref to fork from
+        :return: Nessie tag object
         """
         ref_json = ReferenceSchema().dump(Tag(tag, ref))
-        create_reference(self._base_url, ref_json, self._ssl_verify)
+        ref_obj = create_reference(self._base_url, ref_json, self._ssl_verify)
+        return cast(Tag, ReferenceSchema().load(ref_obj))
 
     def delete_tag(self: "NessieClient", tag: str, hash_: str) -> None:
         """Delete a tag.
@@ -138,10 +142,15 @@ class NessieClient(object):
         """
         return (ContentsSchema().load(get_table(self._base_url, ref, _format_key(i), self._ssl_verify)) for i in tables)
 
-    def commit(self: "NessieClient", branch: str, old_hash: str, reason: Optional[str] = None, *ops: Operation) -> None:
+    def commit(
+        self: "NessieClient", branch: str, old_hash: str, reason: Optional[str] = None, author: Optional[str] = None, *ops: Operation
+    ) -> Branch:
         """Modify a set of Nessie tables."""
         meta = CommitMeta(message=reason if reason else "")
-        commit(self._base_url, branch, MultiContentsSchema().dumps(MultiContents(meta, list(ops))), old_hash)
+        if author:
+            meta.author = author
+        ref_obj = commit(self._base_url, branch, MultiContentsSchema().dumps(MultiContents(meta, list(ops))), old_hash)
+        return cast(Branch, ReferenceSchema().load(ref_obj))
 
     def assign_branch(self: "NessieClient", branch: str, to_ref: str, old_hash: Optional[str] = None) -> None:
         """Assign a hash to a branch."""
@@ -159,15 +168,15 @@ class NessieClient(object):
         tag_json = ReferenceSchema().dumps(Tag(tag, self.get_reference(to_ref).hash_))
         assign_tag(self._base_url, tag, tag_json, old_hash, self._ssl_verify)
 
-    def merge(self: "NessieClient", branch: str, to_branch: str, old_hash: Optional[str] = None) -> None:
+    def merge(self: "NessieClient", from_branch: str, onto_branch: str, old_hash: Optional[str] = None) -> None:
         """Merge a branch into another branch."""
         if not old_hash:
-            old_hash = self.get_reference(branch).hash_
+            old_hash = self.get_reference(onto_branch).hash_
         assert old_hash is not None
-        to_hash = self.get_reference(to_branch).hash_
-        assert to_hash is not None
-        merge_json = MergeSchema().dump(Merge(to_hash))
-        merge(self._base_url, branch, merge_json, old_hash, self._ssl_verify)
+        from_hash = self.get_reference(from_branch).hash_
+        assert from_hash is not None
+        merge_json = MergeSchema().dump(Merge(from_hash))
+        merge(self._base_url, onto_branch, merge_json, old_hash, self._ssl_verify)
 
     def cherry_pick(self: "NessieClient", branch: str, old_hash: Optional[str] = None, *hashes: str) -> None:
         """Cherry pick a list of hashes to a branch."""
@@ -177,9 +186,7 @@ class NessieClient(object):
         transplant_json = TransplantSchema().dump(Transplant(list(hashes)))
         cherry_pick(self._base_url, branch, transplant_json, old_hash, self._ssl_verify)
 
-    def get_log(
-        self: "NessieClient", start_ref: str, max_result_hint: Optional[int] = None, page_token: Optional[str] = None
-    ) -> Generator[CommitMeta, Any, None]:
+    def get_log(self: "NessieClient", start_ref: str, **filtering_args: Any) -> Generator[CommitMeta, Any, None]:
         """Fetch all logs starting at start_ref.
 
         start_ref can be any ref.
@@ -188,9 +195,13 @@ class NessieClient(object):
             this will load the log into local memory and filter at the client. Currently there are no
             primitives in the REST api to limit logs or perform paging. TODO
         """
+        page_token = filtering_args.get("pageToken", None)
 
         def fetch_logs(token: Optional[str] = page_token) -> LogResponse:
-            fetched_logs = list_logs(self._base_url, start_ref, max_result_hint, token, self._ssl_verify)
+            if token:
+                filtering_args["pageToken"] = token
+
+            fetched_logs = list_logs(base_url=self._base_url, ref=start_ref, ssl_verify=self._ssl_verify, **filtering_args)
             log_schema = LogResponseSchema().load(fetched_logs)
             return log_schema
 
@@ -201,7 +212,7 @@ class NessieClient(object):
                 for i in log_schema.operations:
                     yield i
                 if log_schema.has_more:
-                    log_schema = fetch_logs(log_schema.token)
+                    log_schema = fetch_logs(token=log_schema.token)
                 else:
                     break
 
