@@ -100,23 +100,13 @@ def test_log() -> None:
     empty_hash = refs[0].hash_
     _run(
         runner,
-        [
-            "contents",
-            "--set",
-            "foo.bar",
-            "--ref",
-            "main",
-            "-m",
-            "test_message",
-            "-c",
-            empty_hash,
-        ],
-        input=ContentsSchema().dumps(IcebergTable("/a/b/c")),
+        ["contents", "--set", "foo.bar", "--ref", "main", "-m", "test_message", "-c", empty_hash, "--author", "nessie_user1"],
+        input=ContentsSchema().dumps(IcebergTable("uuid", "/a/b/c")),
     )
     result = _run(runner, ["--json", "contents", "foo.bar"])
     tables = ContentsSchema().loads(result.output, many=True)
     assert len(tables) == 1
-    assert tables[0] == IcebergTable("/a/b/c")
+    assert tables[0] == IcebergTable("uuid", "/a/b/c")
     result = _run(runner, ["--json", "log"])
     logs = simplejson.loads(result.output)
     assert len(logs) == 1
@@ -126,13 +116,46 @@ def test_log() -> None:
     result = _run(runner, ["--json", "contents", "--list"])
     entries = EntrySchema().loads(result.output, many=True)
     assert len(entries) == 1
-    _run(runner, ["--json", "contents", "--delete", "foo.bar", "--ref", "main", "-m", "delete_message", "-c", logs[0]["hash"]])
+    _run(
+        runner,
+        [
+            "--json",
+            "contents",
+            "--delete",
+            "foo.bar",
+            "--ref",
+            "main",
+            "-m",
+            "delete_message",
+            "-c",
+            logs[0]["hash"],
+            "--author",
+            "nessie_user2",
+        ],
+    )
     result = _run(runner, ["--json", "log"])
     logs = simplejson.loads(result.output)
     assert len(logs) == 2
     result = _run(runner, ["--json", "log", "{}..{}".format(logs[0]["hash"], logs[1]["hash"])])
     logs = simplejson.loads(result.output)
     assert len(logs) == 1
+    result = _run(runner, ["--json", "log"])
+    logs = simplejson.loads(result.output)
+    assert len(logs) == 2
+    result = _run(runner, ["--json", "log", "--author", "nessie_user1"])
+    logs = simplejson.loads(result.output)
+    assert len(logs) == 1
+    result = _run(runner, ["--json", "log", "--author", "nessie_user2"])
+    logs = simplejson.loads(result.output)
+    assert len(logs) == 1
+    result = _run(runner, ["--json", "log", "--author", "nessie_user2", "--author", "nessie_user1"])
+    logs = simplejson.loads(result.output)
+    assert len(logs) == 2
+    # the committer is set on the server-side and is empty if we're not logged
+    # in when performing a commit
+    result = _run(runner, ["--json", "log", "--committer", ""])
+    logs = simplejson.loads(result.output)
+    assert len(logs) == 2
 
 
 @pytest.mark.vcr
@@ -200,7 +223,7 @@ def test_assign() -> None:
             "-c",
             empty_hash,
         ],
-        input=ContentsSchema().dumps(IcebergTable("/a/b/c")),
+        input=ContentsSchema().dumps(IcebergTable("uuid", "/a/b/c")),
     )
     _run(runner, ["branch", "main", "dev", "--force"])
     result = _run(runner, ["--json", "branch"])
@@ -244,7 +267,7 @@ def test_merge() -> None:
             "-c",
             empty_hash,
         ],
-        input=ContentsSchema().dumps(IcebergTable("/a/b/c")),
+        input=ContentsSchema().dumps(IcebergTable("uuid", "/a/b/c")),
     )
     refs = ReferenceSchema().loads(_run(runner, ["--json", "branch", "-l", "main"]).output, many=True)
     main_hash = next(i.hash_ for i in refs if i.name == "main")
@@ -281,7 +304,7 @@ def test_transplant() -> None:
             "-c",
             empty_hash,
         ],
-        input=ContentsSchema().dumps(IcebergTable("/a/b/c")),
+        input=ContentsSchema().dumps(IcebergTable("uuid", "/a/b/c")),
     )
     _run(
         runner,
@@ -296,7 +319,7 @@ def test_transplant() -> None:
             "-c",
             empty_hash,
         ],
-        input=ContentsSchema().dumps(IcebergTable("/a/b/c")),
+        input=ContentsSchema().dumps(IcebergTable("uuid", "/a/b/c")),
     )
     _run(
         runner,
@@ -311,7 +334,7 @@ def test_transplant() -> None:
             "-c",
             empty_hash,
         ],
-        input=ContentsSchema().dumps(IcebergTable("/a/b/c")),
+        input=ContentsSchema().dumps(IcebergTable("uuid", "/a/b/c")),
     )
     refs = ReferenceSchema().loads(_run(runner, ["--json", "branch", "-l"]).output, many=True)
     main_hash = next(i.hash_ for i in refs if i.name == "main")
